@@ -1,4 +1,3 @@
-
 import sys
 from argparse import ArgumentParser
 
@@ -9,22 +8,22 @@ def wemo():
     parser = ArgumentParser()
 
     parser.add_argument("--timeout", type=int, default=5,
-        help="Time in seconds to allow for discovery")
+                        help="Time in seconds to allow for discovery")
     subparsers = parser.add_subparsers()
 
     stateparser = subparsers.add_parser("switch",
-        help="Turn a WeMo Switch on or off")
+                                        help="Turn a WeMo Switch on or off")
     stateparser.add_argument("device", help="Name of the device")
     stateparser.add_argument("state", help="'on' or 'off")
 
     subparsers.add_parser("list",
-        help="List all devices found in the environment")
+                          help="List all devices found in the environment")
 
     args = parser.parse_args()
 
     ls = state = None
 
-    if (getattr(args, 'device', None)):
+    if getattr(args, 'device', None):
         if args.state.lower() in ("on", "1", "true"):
             state = "on"
         elif args.state.lower() in ("off", "0", "false"):
@@ -45,7 +44,9 @@ def wemo():
             print "Motion: ", motion.name
 
     try:
-        Environment(on_switch, on_motion).discover(args.timeout)
+        env = Environment(on_switch, on_motion, with_subscribers=False)
+        env.start()
+        env.discover(args.timeout)
     except KeyboardInterrupt:
         sys.exit(0)
 
